@@ -619,9 +619,14 @@ scan(struct arglist * env, struct in_addr dst, unsigned long rtt)
 	}
 
 	comm_send_status(globals, hname, "portscan", num, num);
+#if 0
+        plug_set_key(env, "Host/num_ports_scanned", ARG_INT, (void*)num);
+#endif
 	close(soc);
 	bpf_close(bpf);
 	if(ports != NULL)efree(&ports);
+	if (num >= 65535)
+	  plug_set_key(env, "Host/full_scan", ARG_INT, (void*) 1);
 	return 0;
 }
 
@@ -645,7 +650,7 @@ PlugExport int
 plugin_init(struct arglist * desc)
 {
 	plug_set_id(desc, 11219);
-	plug_set_version(desc, "$Revision: 1.12 $");
+	plug_set_version(desc, "$Revision: 1.15 $");
 
 
 
@@ -690,5 +695,6 @@ plugin_run(struct arglist * env)
 
 	scan(env, *dst, rtt);
 	plug_set_key(env, "Host/scanned", ARG_INT, (void *) 1);
+	plug_set_key(env, "Host/scanners/synscan", ARG_INT, (void*)1);
 	return 0;
 }
